HttpError class

Server returned an error status code.

Inheritance
Implementers
Annotations

Constructors

HttpError({required int statusCode, required String message, dynamic responseBody, Map<String, List<String>>? responseHeaders, RequestKey? requestKey, Duration? elapsed, Object? cause, StackTrace? stackTrace})
const

Properties

cause Object?
The underlying cause, if any.
finalinherited
elapsed Duration?
Time elapsed before the error occurred.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isRetryable bool
Whether this error is retryable (5xx or 429).
no setter
message String
Human-readable error message.
finalinherited
requestKey RequestKey?
The request key that failed, if available.
finalinherited
responseBody → dynamic
The response body, if available.
final
responseHeaders Map<String, List<String>>?
Response headers, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Stack trace from the underlying error.
finalinherited
statusCode int?
HTTP status code, if applicable.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited